# Change Log
All notable changes to the Heap library will be documented in this file.

The format is based on [Keep a Changelog][cl] and this project adheres to
[Semantic Versioning][sv].

[cl]: http://keepachangelog.com/
[sv]: http://semver.org/


## [0.9.1] 2019-03-22
### Fixed
- Fix issue where null fragments would cause apps to crash. [HEAP-8475, 
HEAP-8477]

## [0.9.0] - 2019-03-20
A critical issue was identified in this release, and it is not recommended to
use this version of the SDK.
### Added
- Allow ignoring events from parts of the view hierarchy, both declaratively
 via XML view tags, and programmatically by calling `Heap.ignore()` on the
 view. 
- Capture page transition events for changes to the visible page in a
 ViewPager 
- Heap now captures events for androidx equivalents of support library
 elements. 
### Changed
- Heap is now enabled by the setting `ext.heapEnabled` instead of the the
 `enabled` key in the `ext.heap` map. Both locations are consulted for
 compatibility, but the `ext.heap` map location is deprecated. 
- The Heap Gradle plugin can now also be applied before the Android Gradle
 plugin if using Gradle >= 4.8. 
- The Heap Gradle plugin attempts to reduce configuration overhead by using
 the task configuration avoidance APIs when used with Android Gradle Plugin
 versions 3.3 and higher. 
### Deprecated
- Enabling Heap via `ext.heap = ["enabled": true]` is deprecated and will be
 removed in a future version; use `ext.heapEnabled` instead. 
- Support for Android Gradle Plugin versions earlier than 3.0.0 is deprecated
 and will be removed in a future release.
### Fixed
- Fix an issue with `EditText` change events sometimes having incorrect
 timestamps, leading to dropped events. 
- Fix potential issue with tracking changes to set of visible fragments.

## [0.8.3] - 2019-01-23
### Added
- Text changes in EditText fields are now captured if they have at least one 
TextWatcher added 
- The user identity can now be reset to an anonymous state with 
`Heap.resetIdentity()` 
- The Heap library now specifies a minimum SDK version of 14 to match our 
actual use of platform libraries 
### Changed
- Request bodies are now compressed with gzip for size efficiency 

## [0.8.2] - 2019-01-05
### Added
- Heap client library now specifies a target SDK version, which prevents the
 manifest merger from automatically adding the implicit system permissions
 `READ_PHONE_STATE`, `READ_EXTERNAL_STORAGE`, and `WRITE_EXTERNAL_STORAGE` to
 users' apps 

## [0.8.1] - 2018-12-17
### Fixed
- Heap plugin works for Android Gradle Plugin version 3.2.1. 
- Heap plugin instruments Android App Bundles (note: dynamic modules are not 
supported). 

## [0.8.0] - 2018-12-05
### Added
- Heap now autotracks when fragments are added or removed from view, and
 includes visible fragments as an event property on all events 
### Changed
- Heap plugin looks for the heap extension on flavors and default config as
 well as build types 
- The Gradle plugin will error out if used with Android Gradle Plugin 3.2.0 or
 higher. This is a temporary measure as we add compatibility for AGP 3.2+ and
 app bundles. 
### Removed
- Heap no longer sends session and pageview events if the build plugin did not
 apply Heap properly, or if the app is running under instant run. This was
 confusing when troubleshooting, as seeing some events could make it look like
 Heap was installed properly when it was not. 
### Fixed
- Fixed an issue with the included proguard rules that could result in a
 NoSuchMethodError at runtime 

## [0.7.5] - 2018-10-15
### Added
- Proguard rules are now bundled in the client library, removing the need to
 add them manually when integrating 
- Heap plugin now instruments clicks on ActionMenuViews 
- Heap plugin now instruments clicks on links in TextViews 
- Heap plugin checks the minSdkVersion before building to avoid confusing dex 
magic errors 
### Changed
- Heap plugin logs a warning if the variant being built doesn't have Heap
 enabled 
- Heap Android artifacts are now available on jcenter 
### Fixed
- Removed some blocking IO from the Heap.init() call path 

## [0.7.4] - 2018-09-06
### Added
- Heap plugin now instruments BottomNavigationView clicks 
### Changed
- Custom events can now be sent from the background 

## [0.7.3] - 2018-08-27
### Fixed
- Heap library now shades its well-known protobuf types, preventing clashes 
with other libraries, eg Firebase Firestore and Firebase In-App Messaging. 

## [0.7.2] - 2018-08-17
### Added
- Heap plugin now instruments TabHost clicks. 
### Changed
- Heap library now includes device form factor with event data. 

## [0.7.1] - 2018-07-17
### Changed
- Read the complete response body from the Heap endpoint, and close the 
response stream. This should reduce the number of 'socket not closed' warnings 
### Fixed
- Heap.identify triggers as expected when called immediately after Heap.init. 

## [0.7.0] - 2018-05-11
### Added
- Include gradle tasks to print individual licenses used by library. For a list 
of tasks, run `./gradlew tasks` and refer to the "Heap tasks" section. 
- Include this changelog in the released JAR files
- Support Linux build environments 
### Fixed
- Properly fail build if instrumentation fails 
- Fix an issue where dexes numbered above 99 were not included in the 
instrumented APK 
- Fix issue with 400 response codes from track endpoint

## [0.6.0] - 2018-03-26
### Changed
- Heap plugin now immediately aborts with clear exception message on non-macOS 
platforms 
### Removed
- `Heap.setEnvId` and `Heap.setInterval` methods 
### Fixed
- Fix typo in Heap Build Log Warning message about enabling Heap (comma should 
have been a colon).
- Fix bug that prevented apps from building in Android Studio 3 when Instant 
Run was enabled.

## [0.5.2] - 2018-03-08
### Fixed
- Fix BuildConfig error that occurs in Gradle versions 4.1 and higher by 
removing resource value injection out of variant prebuild doFirst action block 
and into general afterEvaluate block of HeapPlugin.apply method 
- Fix add user properties 
- Fix socket resource StrictMode violation 

## [0.5.1] - 2018-03-01
### Added
- Debug information on BuildConfig error 

## [0.5.0] - 2018-02-13
### Added
- Capture Android toggle switches 
- Capture Android radio buttons 

### Fixed
- Fix uncaught exceptions 
